@@ -32,7 +32,7 @@ class CRUD(APIRouter):
                 loop = asyncio.new_event_loop()
                 asyncio.set_event_loop(loop)
 
-            loop.run_until_complete(asyncio.gather([database]))
+            loop.run_until_complete(asyncio.gather(database))
         else:
             database()
 
